RESET_COLOR = '\033[0m'

COLOR_CODES = {
    'blue': '\033[1;34m',  # blue
    'green': '\033[1;32m',  # green
    'yellow': '\033[1;33m',  # yellow
    'red': '\033[1;31m',  # red
}


def color_msg(level, msg):
    return COLOR_CODES[level] + msg + RESET_COLOR



# 输入输出各种颜色的字体
from colors import color_msg
# 打印版本详情信息
from infos import printinfos
# 引入robot类
from robot import Robot


def main():
    printinfos()
    userName = input(color_msg('green', '👉   请输入您的姓名：'))
    robot = Robot(userName)
    chatString = input(color_msg('red', '👉   请输入您想说的的话（输入为空自动结束）：'))
    while chatString != '':
        print(color_msg('blue', '💁   ' + robot.Chatting(chatString)))
        chatString = input(color_msg('red', '👉   请输入您想说的的话（输入为空自动结束）：'))

main()



import requests
import json
import base64
from functools import reduce


class Robot(object):
    # 定义key
    key = 'b7eb33f02fd14c8e8316f617577764c2'

    # 定义用户姓名
    def __init__(self, userName):
        super(Robot, self).__init__()
        self.userName = bytes.decode(
            base64.urlsafe_b64encode(userName.encode()))

    # 聊天操作
    def Chatting(self, info):
        # 定义requestUrl
        requestUrl = 'http://www.tuling123.com/openapi/api?key=' + \
            self.key + '&info=' + info + '&userid' + self.userName
        response = json.loads(requests.get(requestUrl).text)
        responseCode = int(response['code'])
        # 文本类信息
        if responseCode == 100000:
            return response['text']
        # 链接类信息 / 菜谱类信息
        elif responseCode == 200000:
            return response['text'] + '\n' + response['url']
        # 新闻类信息
        elif responseCode == 302000:
            # 定义reduce的迭代函数，使用join拼接字符串
            def computedStr(pre, current):
                stringArray = [
                    '\n',
                    '看点：',
                    current['article'],
                    '\n',
                    '来源：',
                    current['source'],
                    '\n',
                    '链接：',
                    current['detailurl'],
                ]
                return pre + ' '.join(stringArray)
            return response['text'] + reduce(computedStr, response['list'], '')
        else:
            return response['text']



from setuptools import setup, find_packages

setup(
    name='terminalchatrobot',
    version='0.1.2',
    keywords=('terminal', 'chat', 'robot'),
    description='It is a terminal robot which can chat with you.',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Libraries',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],
    license='MIT License',
    install_requires=['requests'],

    entry_points={
        'console_scripts': [
            'terminalchatrobot = terminalchatrobot.main:main'
        ]
    },

    author='xingbofeng',
    author_email='503908971@qq.com',

    packages=find_packages(),
    platforms='any',
)
